Installation
============

The easiest way to install the package is using pip::

    $ pip install starmatrix

This will also install some dependencies if they are not found in the system: **numpy**, **scipy** and **pyyaml**

Uninstall
---------

To remove Starmatrix from your system run::

    $ pip uninstall starmatrix
